'use strict';

const path = require('path');
const componentFunctions = require('./lib/component')($app);

$app.postUnpackFiles = function() {
  // Needed for calling to $app.start and similar while initializing as non-root
  $app.installedAsRoot = false;
  $os.addGroup($app.systemGroup);
  $os.addUser($app.systemUser, {gid: $app.systemGroup});
  // Create files and directories
  $file.mkdir($app.tmpDir);
  $file.link($app.installdir, $file.join($app.installation.root, 'apache2'));
  // Enable useful modules
  $app.helpers.configureModules(
    [
      'mod_version',
      'mod_socache_shmcb',
      'mod_negotiation',
      'mod_ssl',
      'mod_http2',
      'mod_slotmem_shm',
      'mod_deflate',
      'mod_rewrite',
      'mod_proxy.*',
      // For server information (used for metrics)
      'mod_status',
    ],
    'enable'
  );
  // We don't enable mod_proxy_hcheck nor mod_http2 by default but configureModule enables all mod_proxy* modules
  $app.helpers.configureModules(['mod_proxy_hcheck', 'mod_http2'], 'disable');
  // Additional configuration
  $app.helpers.configureEntry('Include conf/extra/httpd-default.conf', 'enable');
  $app.helpers.setupBitnamiConfig();
  $app.helpers.httpoxyPatch();
  $app.writeSetenv({binPaths: [path.join($app.installdir, 'bin'), path.join($app.installation.root, 'common/bin')]});
  // Create monit/gonit and logrotate configuration, which does not depend on the service being setup
  componentFunctions.createExtraConfigurationFiles([
    {type: 'monit', path: $app.monitFile, params: {service: 'apache', pidFile: $app.pidFile}},
    {type: 'logrotate', path: $app.logrotateFile, params: {logPath: $file.join($app.logsDir, '*log')}},
  ]);
};

$app.postInstallation = function() {
  if ($file.writable($app.confFile)) {
    // Only modify if the file is writable and not mounted as a ConfigMap
    $app.helpers.setupPorts();
  } else {
    $app.warn(`Not modifying the ${$app.confFile} file as it is not writable`);
  }
  // Restore persisted configuration files (deprecated)
  if ($file.exists('/bitnami/apache/conf')) {
    $app.warn(`The directory '/bitnami/apache/conf' was externally mounted. This is a legacy configuration and will be `
      + `deprecated soon. Please mount configuration files at '${$app.confDir}' instead. Find an example at: `
      + `https://github.com/bitnami/bitnami-docker-apache#full-configuration`);
    $app.warn(`Restoring configuration at '/bitnami/apache/conf' to '${$app.confDir}'...`);
    $file.delete($app.confDir);
    $file.link('/bitnami/apache/conf', $app.confDir);
  }
};

$app.exports = {
  replaceHtaccessFiles: $app.helpers.replaceHtaccessFiles,
  removeHtaccessFile: $app.helpers.removeHtaccessFile,
  addVhost: $app.helpers.addVhost,
  removeVhost: $app.helpers.removeVhost,
  configureModules: $app.helpers.configureModules,
  configureEntry: $app.helpers.configureEntry,
  reload: $app.helpers.reload,
  resize: $app.helpers.resize,
};
